@@ -26,8 +26,8 @@ class Repo(Git):
         repo.init(user or User(name='Giterator', email='giterator@example.com'))
         return repo
 
-    def commit(self, msg: str, author_date: Date = None, commit_date: Date = None):
-        super().commit(msg, author_date, commit_date or author_date)
+    def commit(self, msg: str, author_date: Date = None, commit_date: Date = None) -> str:
+        return super().commit(msg, author_date, commit_date or author_date)
 
     def commit_content(
         self,
@@ -36,7 +36,7 @@ class Repo(Git):
         *,
         tag: str = None,
         branch: str = None,
-    ) -> None:
+    ) -> str:
         """
         Write new context based on the prefix and then commit it
         at the specified datetime, or using at a sequence of increasing
@@ -45,6 +45,7 @@ class Repo(Git):
         if branch:
             self.branch(branch)
         (self.path / prefix).write_text(f'{prefix} content')
-        self.commit('a commit', dt or self._clock.now())
+        commit = self.commit('a commit', dt or self._clock.now())
         if tag:
             self.tag(tag)
+        return commit
